Kanadam.com

Forum Bize ücretsiz danışın!

## Kanada’da yabancı öğrencileri etkileyecek yeni düzenlemeler

26 Nisan 2014, Yorumlar Kapalı

Kanada hükümeti Şubat 2014′te yabancı öğrenciler için mevcut yürürlükte olan çalışma ve okuma izinlerinin (work and study permits) suistimalini önlemek amacıyla yeni düzenlemeler yapacağını açıkladı. 1 Haziran itibariyle yürürlüğe girecek […]

## Kanada’ya internet girişimcisi olarak gitmek

16 Nisan 2014, Yorumlar Kapalı

Webrazzi’de yayınlanan bir haberde Kanada’nın girişimcileri ülkeye çekebilmek amacıyla oluşturduğu “Startup Visa” programına değinildi. “Silikon Vadisi’ne yaklaşık 1 saat 50 dakikalık uçak yolculuğu mesafesindeki Kanada, devlet desteğiyle girişimcilerin yeni rotası […]

## Forum’da soru ve yanıtlarınızı paylaşın

14 Mart 2013, Yorumlar Kapalı

Kanadam.com Forum‘da şu ana kadar 2500′e yakın soru soruldu ve 30000′in üzerinde yanıt paylaşıldı. Üye değilseniz üyelik formunu doldurarak foruma katılabilirsiniz.

## Kanada’da geçici işçiler

04 Haziran 2012, Yorumlar Kapalı

İngiltere’li yazar Kenan Malik bugün (3 Haziran 2012) UBC’de yaptığı konuşmada Kanada’nın geçici işçiler konusundaki göçmenlik politikasını eleştirdi. Yazar, Kanada’nın muhafazakar hükümetinin bu politikalarını Avrupa’nın önde gelen ekonomilerinden İngiltere, Fransa […]

## VIDEO: Kanada’da eğitim sonrası göçmenlik semineri (30 dakika)

13 Mart 2012, Yorumlar Kapalı

Kanada’da göçmenlik ve eğitim hakkında sizleri bilgilendirmek amacıyla 7 Eylül Çarşamba günü Vancouver’da toplandık. Toplantıda Immigration Consultants of Canada Regulatory Council (ICCRC) üyesi, lisanslı göçmenlik danışmanımız Banu Veznikli Kanada’ya göçmenlik hakkında […]

## Kanada’ya göçmenlikte meslek kategorileri değişti

28 Haziran 2010, 1 yorum

26 Haziran 2010′da Kanada’ya göçmenliği düzenleyen bakanlık, ülkenin ekonomik gelişimini gözönünde bulundurarak, nitelikli işçi alımında belirledikleri öncelikli mesleklerde değişiklik yaptığını açıkladı. Detaylı haber için buraya tıklayın. Bu açıklama ile meslek listesine yeni […]

#### Güncel yazılar

### Kanada’da yabancı öğrencileri etkileyecek yeni düzenlemeler

Kanada hükümeti Şubat 2014′te yabancı öğrenciler için mevcut yürürlükte olan çalışma ve okuma izinlerinin (work and study permits) ...

### Kanada’ya internet girişimcisi olarak gitmek

Webrazzi’de yayınlanan bir haberde Kanada’nın girişimcileri ülkeye çekebilmek amacıyla oluşturduğu “Startup Visa” programına değinil ...

### Forum’da soru ve yanıtlarınızı paylaşın

Kanadam.com Forum‘da şu ana kadar 2500′e yakın soru soruldu ve 30000′in üzerinde yanıt paylaşıldı. Üye değilseniz üyelik f ...

### Kanada göçmenlik başvurusu reddine itiraz etmenin yolları

Eğer Kanada’ya göçmenlik başvurunuzun sonucunda elinize bir red yazısı geçtiyse panik olmayın. Kararın temyizi için başvurunuzun nite ...

### Kanada’da geçici işçiler

İngiltere’li yazar Kenan Malik bugün (3 Haziran 2012) UBC’de yaptığı konuşmada Kanada’nın geçici işçiler konusundaki göç ...

### VIDEO: Kanada’da eğitim sonrası göçmenlik semineri (30 dakika)

Kanada’da göçmenlik ve eğitim hakkında sizleri bilgilendirmek amacıyla 7 Eylül Çarşamba günü Vancouver’da toplandık. Toplantıda Im ...

### Kanada’ya göçmenlikte meslek kategorileri değişti

26 Haziran 2010′da Kanada’ya göçmenliği düzenleyen bakanlık, ülkenin ekonomik gelişimini gözönünde bulundurarak, nitelikli işç ...

### Kanada’da bir üniversiteye transfer nasıl gerçekleştirilir?

Türkiye’de üniversite eğitimi almakta olan herkes dilerse, eğitiminin herhangi bir aşamasında Kanada’da bir üniversiteye transfer b ...

### Kanada’ya yatırımcı göçmen sayısında artış olabilir

Kanada’da geçtiğimiz aylarda bazı ekonomistler tarafından yatırımcı göçmenler konusunda yapılan bir araştırmanın bazı önemli sonuçla ...

#### Kanada göçmenliği ve vatandaşlığı

- ##### Kanada’ya internet girişimcisi olarak gitmek

  16 Nisan 2014, Yorumlar Kapalı

- ##### Kanada göçmenlik başvurusu reddine itiraz etmenin yolları

  12 Haziran 2012, Yorumlar Kapalı

- ##### Kanada’da geçici işçiler

  04 Haziran 2012, Yorumlar Kapalı

- ##### VIDEO: Kanada’da eğitim sonrası göçmenlik semineri (30 dakika)

  13 Mart 2012, Yorumlar Kapalı

#### Kanada'da eğitim

- ##### Kanada’da yabancı öğrencileri etkileyecek yeni düzenlemeler

  26 Nisan 2014, Yorumlar Kapalı

- ##### Kanada’da bir üniversiteye transfer nasıl gerçekleştirilir?

  21 Mayıs 2010, 2 yorum

- ##### Kanada’da hukuk İngilizcesi

  12 Mart 2010, Yorumlar Kapalı

- ##### Victoria Üniversitesi İngilizce Dil Merkezi ile İstanbul ve İzmir’deyiz

  01 Ocak 2010, Yorumlar Kapalı